@@ -27,7 +27,7 @@ class JSON(object):
         f['modified'] = f['modified'].ctime()
 
     return 'application/json', json.dumps(data['files'])
-  
+
 class RSS(object):
   """RSS for indices"""
 
@@ -38,7 +38,7 @@ class RSS(object):
 
   def __call__(self, request, data):
     items = [ PyRSS2Gen.RSSItem(title=item['name'],
-                                description=item['description'] or item['name'],
+                                description=item['description'] or item.get('title') or item['name'],
                                 pubDate=item['modified'],
                                 guid=PyRSS2Gen.Guid(link(request, item['path'])))
               for item in data['files'] ]
