@@ -9,14 +9,15 @@ from pkg_resources import iter_entry_points
 
 class FormatterBase(object):
     """
-    abstract base class if you want to use __init__ methods 
-    in the form of 
+    abstract base class if you want to use __init__ methods
+    in the form of
     'arg1, arg2, arg3, kw1=foo, kw2=bar, kw3=baz
     """
 
     defaults = {} # default values for attrs to be set on the instance
-    
+
     def __init__(self, string):
+        self._string = string
         args = [ i.strip() for i in string.split(',')]
         for index, arg in enumerate(args):
             if '=' in arg:
@@ -37,7 +38,7 @@ class FormatterBase(object):
 
 class Ignore(object):
     """
-    ignore files of a glob patterns.  
+    ignore files of a glob patterns.
     These files will not be linked to in the template.
     e.g. /ignore = .* *.pdf  # don't list dotfiles and PDFs
     """
@@ -58,11 +59,11 @@ class Ignore(object):
 
 class All(object):
     """
-    only pass files of a certain pattern; 
+    only pass files of a certain pattern;
     the inverse of ignore
     calling all with no arguments means only files with descriptions are used
     """
-    
+
     def __init__(self, pattern):
         self.match = pattern.split()
 
@@ -79,21 +80,22 @@ class All(object):
                 if f['description'] is not None:
                     _files.append(f)
         data['files'] = _files
-        
+
 class Sort(FormatterBase):
     """
-    determines how to sort the files in a directory; 
+    determines how to sort the files in a directory;
     right now only by case-insensitive alphabetically
     * reverse : reverse the order of the sorting
     """
     defaults = {'order': 'name'}
-    
+
     def __init__(self, pattern):
         FormatterBase.__init__(self, pattern)
         self.orders = {'name': self.name,
                        'random': self.random,
                        }
-    
+        # TODO: date
+
     def __call__(self, request, data):
 
         sort = self.orders.get(request.GET.get('order', self.order), self.name)
@@ -121,7 +123,7 @@ class Order(object):
             self.file = value
         else:
             self.order = [i.strip() for i in pattern.split(',')]
-    
+
     def __call__(self, request, data):
 
         if self.file:
@@ -162,8 +164,8 @@ class FilenameDescription(FormatterBase):
 
 class TitleDescription(FormatterBase):
     """
-    splits a description into a title and a description via a separator in 
-    the description.  The template will now have an additional variable, 
+    splits a description into a title and a description via a separator in
+    the description.  The template will now have an additional variable,
     'title', per file
     Arguments:
     * separator: what separator to use (':' by default)
@@ -171,8 +173,20 @@ class TitleDescription(FormatterBase):
     # XXX what about setting the page title?
 
     defaults = { 'separator': ':' }
-        
+
     def __call__(self, request, data):
+
+        # title webpage
+        title = self._string
+        if ':' in title:
+            _title, url = [i.strip() for i in title.split(':', 1)]
+            if '://' in url:
+                # XXX could also use urlparse
+                title = _title
+                data['link'] = url
+        data['title'] = title
+
+        # title files
         for f in data['files']:
             if f['description'] and self.separator in f['description']:
                 title, description = f['description'].split(self.separator, 1)
@@ -191,7 +205,7 @@ class Links(FormatterBase):
     allow list of links per item:
     foo.html = description of foo; [PDF]=foo.pdf; [TXT]=foo.txt
     """
-    
+
     defaults = { 'separator': ';' }
 
     def __call__(self, request, data):
@@ -213,7 +227,7 @@ class Up(object):
 
     def __init__(self, arg):
         self.up = arg.strip()
-    
+
     def __call__(self, request, data):
         path = request.path_info
         if (path != '/') and self.up:
@@ -254,7 +268,7 @@ class Include(object):
     def __call__(self, request, data):
         data['include'] = self.include
 
-        
+
 def formatters():
     formatters = {}
     for entry_point in iter_entry_points('decoupage.formatters'):
