@@ -73,7 +73,7 @@ class Decoupage(object):
                 print >> sys.stderr, e
                 continue
             self.formats[_format.name] = _instance
-        
+
         # pluggable index data formatters
         self.formatters = {}
         for formatter in iter_entry_points('decoupage.formatters'):
@@ -86,17 +86,18 @@ class Decoupage(object):
                 # record the error, but persist
                 print >> sys.stderr, "Couldn't load formatter: %s" % formatter
                 print >> sts.stderr, e
-                continue 
+                continue
             self.formatters[formatter.name] = _formatter
-        
+
         # template loader
-        self.loader = TemplateLoader(self.template_directories, 
+        self.loader = TemplateLoader(self.template_directories,
+                                     variable_lookup="lenient",
                                      auto_reload=self.auto_reload)
 
-        
+
 
     ### methods dealing with HTTP
-        
+
     def __call__(self, environ, start_response):
 
         # boilerplate: request and filename
@@ -106,7 +107,7 @@ class Decoupage(object):
 
         # check to see what we have to serve
         if os.path.exists(path):
-            
+
             if os.path.isdir(path):
                 # serve an index
                 if request.path_info.endswith('/'):
@@ -129,7 +130,7 @@ class Decoupage(object):
                     fileserver = FileTypeTransformer(*args, **kwargs)
                 else:
                     fileserver = self.fileserver
-                    
+
                 fileserver = fileserver(path)
                 return fileserver(environ, start_response)
         else:
@@ -142,12 +143,12 @@ class Decoupage(object):
         """
         return response to a GET requst
         """
-        
-        # ensure a sane path        
+
+        # ensure a sane path
         path = request.path_info.strip('/')
         directory = os.path.join(self.directory, path)
         path = '/%s' % path
-        
+
         # get the configuraton
         conf = self.conf(path)
 
@@ -159,15 +160,10 @@ class Decoupage(object):
         # add a function to get the path to files
         data['filepath'] = lambda *segments: os.path.join(*([directory] + list(segments)))
 
-        # defaults; TODO: make this better
-        # there shouldn't need to be defaults;
-        # iirc, genshi has a mode where these will default to None
-        data['title'] = conf.get('/title')
+        # defaults
         data['directory'] = directory
-        data['include'] = None
         data['css'] = ()
         data['scripts'] = ()
-        data['icon'] = None
 
         # apply formatters
         # XXX this should be cached if not self.auto_reload
@@ -198,7 +194,7 @@ class Decoupage(object):
 
         # render the template
         template = conf.get('/template')
-        local_index = False 
+        local_index = False
         if template is None:
             if 'index.html' in [ f['name'] for f in files ]:
                 local_index = os.path.join(directory, 'index.html')
@@ -251,7 +247,7 @@ class Decoupage(object):
             if filetype == 'file':
                 data['size'] =  os.path.getsize(filepath)
             files.append(data)
-        
+
         # TODO: deal with other links in conf
         for i in conf:
             if i in filenames or i.startswith('/'):
@@ -260,7 +256,7 @@ class Decoupage(object):
                 files.append({'path': i,
                               'name': i,
                               'type': link})
-            
+
         for f in files:
             f['description'] = conf.get(f['name'], None)
 
@@ -304,7 +300,7 @@ class Decoupage(object):
             parent_configuration = self.conf(inherit_directory)
             for key, value in parent_configuration.items():
                 if key.startswith('/') and key not in conf:
-                    conf[key] = value                
+                    conf[key] = value
 
         # cache configuration
         if not self.auto_reload:
@@ -320,5 +316,5 @@ class Decoupage(object):
             if key.startswith('/'):
                 key = key[1:]
                 if key in self.formatters:
-                    formatter = self.formatters[key](value)        
+                    formatter = self.formatters[key](value)
 
